========================================
``psyclone.tests.core.access_info_test``
========================================

.. automodule:: psyclone.tests.core.access_info_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.core.access_info_test
